@@ -107,24 +107,24 @@ def decodeCustomTx(hex:str):
 
     
 
+# TODO: only working in python3.9 not in 3.8!!!
+# class TakeLoan(CustomTx.DfTx):
+#     def __init__(self,vaultId:str,address:str,amounts:list,rpcConnector):
+#         super().__init__()
+#         resAmounts = []
+#         for a in amounts:
+#             amount = a.split('@')
+#             resAmounts.append((float(amount[0]),utils.getTokenId(amount[1],rpcConnector)))
+#         self.params = [CustomTx.CustomTxType.TakeLoan,ParamType.Vault(vaultId),ParamType.Address(address),ParamType.Amounts(resAmounts)]
 
-class TakeLoan(CustomTx.DfTx):
-    def __init__(self,vaultId:str,address:str,amounts:list,rpcConnector):
-        super().__init__()
-        resAmounts = []
-        for a in amounts:
-            amount = a.split('@')
-            resAmounts.append((float(amount[0]),utils.getTokenId(amount[1],rpcConnector)))
-        self.params = [CustomTx.CustomTxType.TakeLoan,ParamType.Vault(vaultId),ParamType.Address(address),ParamType.Amounts(resAmounts)]
-
-class AddPoolLiquidity(CustomTx.DfTx):
-    def __init__(self,amountPerAddress:list[tuple[str,str]],shareAddress:str,rpcConnector):
-        super().__init__()
-        resAddressAmount = []
-        for a in amountPerAddress:
-            amount = a[1].split('@')
-            resAddressAmount.append((a[0],float(amount[0]),utils.getTokenId(amount[1],rpcConnector)))
-        self.params = [CustomTx.CustomTxType.AddPoolLiquidity,ParamType.AddressesWithAmount(resAddressAmount),ParamType.Address(shareAddress)]
+# class AddPoolLiquidity(CustomTx.DfTx):
+#     def __init__(self,amountPerAddress:list[tuple[str,str]],shareAddress:str,rpcConnector):
+#         super().__init__()
+#         resAddressAmount = []
+#         for a in amountPerAddress:
+#             amount = a[1].split('@')
+#             resAddressAmount.append((a[0],float(amount[0]),utils.getTokenId(amount[1],rpcConnector)))
+#         self.params = [CustomTx.CustomTxType.AddPoolLiquidity,ParamType.AddressesWithAmount(resAddressAmount),ParamType.Address(shareAddress)]
 
 @dataclass
 class RPCConnector():
